<?php

namespace InPost\Shipping\GeoWidget;

use Context;
use FrontController;
use InPost\Shipping\Configuration\GeoWidgetConfiguration;
use InPost\Shipping\Configuration\ShipXConfiguration;

class GeoWidgetTokenProvider
{
    protected $geoWidgetConfiguration;
    protected $shipXConfiguration;
    protected $context;

    private $token;

    public function __construct(
        GeoWidgetConfiguration $geoWidgetConfiguration,
        ShipXConfiguration $shipXConfiguration
    ) {
        $this->geoWidgetConfiguration = $geoWidgetConfiguration;
        $this->shipXConfiguration = $shipXConfiguration;
        $this->context = Context::getContext();
    }

    public function getToken()
    {
        if (!isset($this->token)) {
            if ($sandbox = $this->shouldUseSandbox()) {
                $token = $this->geoWidgetConfiguration->getSandboxToken();
            } else {
                $token = $this->geoWidgetConfiguration->getProductionToken();
            }

            $this->token = $token
                ? new GeoWidgetToken($token, $sandbox)
                : false;
        }

        return $this->token ?: null;
    }

    protected function shouldUseSandbox()
    {
        return $this->shipXConfiguration->isSandboxModeEnabled()
            && (
                !$this->context->controller instanceof FrontController
                || $this->geoWidgetConfiguration->shouldUseSandboxOnTheFrontOffice()
            );
    }
}
