<?php
/**
 * Copyright 2021-2022 InPost S.A.
 *
 * NOTICE OF LICENSE
 *
 * Licensed under the EUPL-1.2 or later.
 * You may not use this work except in compliance with the Licence.
 *
 * You may obtain a copy of the Licence at:
 * https://joinup.ec.europa.eu/software/page/eupl
 * It is also bundled with this package in the file LICENSE.txt
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the Licence is distributed on an AS IS basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions
 * and limitations under the Licence.
 *
 * @author    InPost S.A.
 * @copyright 2021-2022 InPost S.A.
 * @license   https://joinup.ec.europa.eu/software/page/eupl
 */

namespace InPost\Shipping\Presenter;

use InPost\Shipping\DataProvider\LanguageDataProvider;
use InPost\Shipping\ShipX\Resource\Point;
use InPostShipping;

class PointPresenter
{
    const TRANSLATION_SOURCE = 'PointPresenter';

    protected $module;
    protected $languageDataProvider;

    public function __construct(
        InPostShipping $module,
        LanguageDataProvider $languageDataProvider
    ) {
        $this->module = $module;
        $this->languageDataProvider = $languageDataProvider;
    }

    public function present(Point $point, $id_lang = null, $format = '%s: %s')
    {
        $locale = null !== $id_lang
            ? $this->languageDataProvider->getLocaleById($id_lang)
            : null;

        return sprintf(
            $format,
            $this->getPointLabel($point, $locale),
            $point->name
        );
    }

    protected function getPointLabel(Point $point, $locale)
    {
        switch ($point->partner_id) {
            case Point::PARTNER_ID_ZABKA_POP:
                return $this->module->l('InPost in Żabka', self::TRANSLATION_SOURCE, $locale);
            default:
                return $this->module->l('InPost parcel locker', self::TRANSLATION_SOURCE, $locale);
        }
    }
}
